@@ -7,7 +7,7 @@ use Stream::Buffered;
 use HTTP::Entity::Parser::OctetStream;
 use Module::Load;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub new {
     my $class = shift;
@@ -25,7 +25,8 @@ sub get_parser {
 
     if (defined $env->{CONTENT_TYPE}) {
         for my $handler (@{$self->{handlers}}) {
-            if (index($env->{CONTENT_TYPE}, $handler->[0]) == 0) {
+            if ( $env->{CONTENT_TYPE} eq $handler->[0] 
+              || index($env->{CONTENT_TYPE}, $handler->[0]) == 0) {
                 return $handler->[1]->new($env, $handler->[2]);
             }
         }
@@ -230,10 +231,14 @@ HTTP::Entity::Parser is able to choose parsers by the instance, HTTP::Body requi
 
 =item L<HTTP::Body>
 
-=item L<HTTP::MultiPartParser>.
+=item L<HTTP::MultiPartParser>
 
 =item L<Plack::Request>
 
+=item L<WWW::Form::UrlEncoded>
+
+HTTP::Entity::Parser uses this for parse application/x-www-form-urlencoded
+
 =back
 
 =head1 LICENSE
